@@ -10,11 +10,12 @@ import logging
 import os
 import sys
 import warnings
+import configparser
+import io
 
 from functools import partial
 
 from six import iterkeys, itervalues, iteritems, ensure_str
-from six.moves import configparser
 
 import jinja2
 import mock
@@ -312,8 +313,7 @@ def retry(*args):
             except args as e:
                 if isinstance(e, GlueError):
                     raise GlueRetryError(e.value)  # type: ignore
-                else:
-                    raise GlueRetryError(e)
+                raise GlueRetryError(e)
         return func_wrapper
     return wrap
 
@@ -696,6 +696,7 @@ class Pipeline(LoggerMixin, object):
             # The failure would then be propagated to `run()` method and it would represent the cause
             # that killed the pipeline.
 
+            # pylint: disable=bad-continuation
             with Action(
                 'executing module',
                 parent=self.action,
@@ -741,10 +742,13 @@ class Pipeline(LoggerMixin, object):
             # to the Sentry. Therefore, adding `_safe_call` (inside `_destroy` which itself was called via
             # `_safe_call`), catching and logging the failure. After that, we simply return the "destroy failure"
             # from `_destroy`, which then causes `_for_each_module` to quit loop immediately, propagating this
-            # destroy failure even further.
+            # destroy failure even further. We do not want to continue with destroying the rest of the modules
+            # as the pipeline state is unknown and could cause external systems to react in possibly risky ways
+            # or propagate misinformation such as a test passing when it actually failed.
 
             # We get either `None` or a failure if an exception was raised by `destroy`. If it's a failure,
             # we can log it with a bit more context.
+            # pylint: disable=bad-continuation
             with Action(
                 'destroying module',
                 parent=self.action,
@@ -946,7 +950,8 @@ class Configurable(LoggerMixin, object):
 
         # Sort options by their names - no code has a strong option on their order, so force
         # one to all users of this helper.
-        option_names = sorted(iterkeys(options), key=lambda x: x[1] if isinstance(x, tuple) else x)
+        # Mypy is not happy about lambda function: https://github.com/python/mypy/issues/9656#issuecomment-718284938
+        option_names = sorted(iterkeys(options), key=lambda x: x[1] if isinstance(x, tuple) else x)  # type: ignore
 
         for names in option_names:
             params = options[names]
@@ -1032,18 +1037,47 @@ class Configurable(LoggerMixin, object):
         # type: (List[str]) -> None
 
         """
-        Parse configuration files. Uses :py:mod:`ConfigParser` for the actual parsing.
-        Updates module's configuration store with values found returned by the parser.
+        Parse configuration files. Uses :py:mod:`configparser` for the actual
+        parsing, and updates module's configuration store with values found
+        returned by `configparser`. This function also replaces `${config_root}`
+        with the path of the module config directory. This is one level up
+        (parent) from where the module configuration file is.
 
         :param list paths: List of paths to possible configuration files.
+
+        Further explanation of `${config_root}` follows:
+
+        There is a use case to reference the parent dir of where the
+        config file is. Certain modules have such configurations:
+
+        playbooks-map = ~/.citool.d/playbooks-map.yaml
+
+        To avoid hardcoding the directory, `${config_root}` can be used:
+
+        playbooks-map = ${config_root}/playbooks-map.yaml
+
+        This makes it possible to store the configuration in any location
+        that may be specified on the command line via `--module-config-path`.
+        Furthermore, it is valid to have multiple configuration files, each
+        overwriting values from the former file.
+
+        Currently (2021-11) a replace of `${config_root}` is done right after
+        reading the file and before parsing it with configparser.
+
+        We cannot use Jinja for this, as the combined config is passed to Jinja.
+        We also cannot use configparser's interpolation, as once interpolated,
+        values do not remain that way, but will be interpolated again upon the
+        next call of any of the configparser's 'read*' methods. Either will
+        result in a bug where `${config_root}` is replaced with the path of
+        another config file's parent dir. This is also the reason why
+        configparser's `read` method is not used and instead each file is read
+        one by one.
+
         """
 
         log_dict(self.debug, 'Loading configuration from following paths', paths)
 
-        parser = configparser.ConfigParser()
-        parsed_paths = parser.read(paths)
-
-        log_dict(self.debug, 'Read configuration files', parsed_paths)
+        parser = configparser.ConfigParser(interpolation=None)
 
         def _inject_value(name, names, params):
             # type: (str, Tuple[str, ...], Dict[str, Any]) -> None
@@ -1079,8 +1113,22 @@ class Configurable(LoggerMixin, object):
 
             Configurable._for_each_option(_inject_value, options)
 
+        parsed_paths = []  # type: List[str]
+
+        for path in paths:
+            if not os.access(path, os.R_OK):
+                self.debug("path '{}' not readable, skipping".format(path))  # pylint: disable=not-callable
+                continue
+            with io.open(path, encoding='utf-8', mode="r") as file_handle:
+                config_data = file_handle.read()
+            config_data = config_data.replace("${config_root}", os.path.dirname(os.path.dirname(path)))
+            parser.read_string(config_data)
+            parsed_paths.append(path)
+
         Configurable._for_each_option_group(_inject_values, self.options)
 
+        log_dict(self.debug, 'Read configuration files', parsed_paths)
+
     @classmethod
     def _create_args_parser(cls, **kwargs):
         # type: (**Any) -> ArgumentParser
@@ -1553,6 +1601,7 @@ class Module(Configurable):
             eval_context_help(self)
         ]
 
+        # pylint: disable=not-callable
         self._parse_args(args,
                          usage='{} [options]'.format(Colors.style(self.unique_name, fg='cyan')),
                          description=docstring_to_help(self.__doc__ or ''),
@@ -1683,9 +1732,9 @@ class Module(Configurable):
         """
 
     def run_module(self, module, args=None):
-        # type: (str, Optional[List[str]]) -> None
+        # type: (str, Optional[List[str]]) -> PipelineReturnType
 
-        self.glue.run_module(module, args or [])
+        return self.glue.run_module(module, args or [])
 
 
 #: Describes one discovered ``gluetool`` module.
@@ -1905,7 +1954,14 @@ class Glue(Configurable):
         """
 
         from .utils import normalize_path_option
-        return normalize_path_option(self.option('module-config-path')) or DEFAULT_MODULE_CONFIG_PATHS
+
+        if self.option('module-config-path'):
+            return normalize_path_option(self.option('module-config-path'))
+
+        if 'GLUETOOL_MODULE_CONFIG_PATHS' in os.environ:
+            return normalize_path_option(os.environ['GLUETOOL_MODULE_CONFIG_PATHS'])
+
+        return DEFAULT_MODULE_CONFIG_PATHS
 
     # pylint: disable=method-hidden
     def sentry_submit_exception(self, *args, **kwargs):
@@ -2050,7 +2106,6 @@ class Glue(Configurable):
         """
 
         stack = inspect.stack()
-        log_dict(self.verbose, 'stack', stack)
 
         # When being called as a regular shared function, the call stack layout should be
         # as follows:
@@ -2102,8 +2157,6 @@ class Glue(Configurable):
             for module in pipeline.modules:
                 context.update(module.eval_context)
 
-        log_dict(self.verbose, 'eval context', context)
-
         return context
 
     @property
@@ -2460,6 +2513,7 @@ class Glue(Configurable):
         Supported environment variables:
 
         * GLUETOOL_CONFIG_PATHS (string) - colon-separated list of gluetool configuration directories
+        * GLUETOOL_MODULE_CONFIG_PATHS (string) - colon-separated list of gluetool modules configuration directories
         * GLUETOOL_TRACING_DISABLE - when set, tracing won't be enabled
         * GLUETOOL_TRACING_SERVICE_NAME (string) - name of the trace produced by tool execution
         * GLUETOOL_TRACING_REPORTING_HOST (string) - a hostname where tracing collector listens
