@@ -72,9 +72,9 @@ ExceptionInfoType = Union[
 LoggingFunctionType = Callable[
     [
         Arg(str),
-        DefaultNamedArg(ExceptionInfoType, 'exc_info'),
-        DefaultNamedArg(Dict[str, Any], 'extra'),
-        DefaultNamedArg(bool, 'sentry')
+        DefaultNamedArg(ExceptionInfoType, 'exc_info'),  # noqa: F821
+        DefaultNamedArg(Dict[str, Any], 'extra'),  # noqa: F821
+        DefaultNamedArg(bool, 'sentry')  # noqa: F821
     ],
     None
 ]
@@ -796,6 +796,7 @@ class LoggingFormatter(logging.Formatter):
     }
 
     #: Colorizers assigned to loglevels
+    # pylint: disable=not-callable
     _level_color = {
         logging.INFO: lambda text: Colors.style(text, fg='green'),
         logging.WARNING: lambda text: Colors.style(text, fg='yellow'),
@@ -896,9 +897,11 @@ class LoggingFormatter(logging.Formatter):
             #
             # Regular sort would yield contexts by their priorities from lower to higher ones, therefore reversed flag.
             # That way we'd start inserting higher priority contexts sooner than lower priority ones.
+
+            # Mypy is not happy about lambda function: https://github.com/python/mypy/issues/9656#issuecomment-718284938
             sorted_contexts = sorted(
                 iterkeys(contexts),
-                key=lambda ctx_name: contexts[ctx_name][0],
+                key=lambda ctx_name: contexts[ctx_name][0],  # type: ignore
                 reverse=True
             )
 
