@@ -29,8 +29,6 @@ import six
 from six import PY2, ensure_str, iteritems, iterkeys
 from six.moves import http_client, urllib
 
-# Don't know why pylint reports "Relative import 'ruamel.yaml', should be 'gluetool.ruamel.yaml'" :(
-# pylint: disable=relative-import
 import ruamel.yaml
 
 from .glue import GlueError, SoftGlueError, GlueCommandError
@@ -49,6 +47,7 @@ if TYPE_CHECKING:
 
 
 # Type variable used in generic types
+# pylint: disable=invalid-name
 T = TypeVar('T')
 
 
@@ -66,6 +65,29 @@ if 'file' not in urlnormalizer.normalizer.SCHEMES:
     urlnormalizer.normalizer.SCHEMES = urlnormalizer.normalizer.SCHEMES + ('file',)
 
 
+# Jinja2 filter - regular expression replace
+def regex_replace(s, find, replace, ignorecase=False, multiline=False):
+    # type: (str, str, str, bool, bool) -> str
+    flags = 0
+    if ignorecase:
+        flags |= re.IGNORECASE
+    if multiline:
+        flags |= re.MULTILINE
+    return re.sub(find, replace, s, 0, flags)
+
+
+# Jinja2 - register custom filters
+jinja2.defaults.DEFAULT_FILTERS['regex_replace'] = regex_replace
+
+
+def regex_escape(s):
+    # type: (str) -> str
+    return re.escape(s)
+
+
+jinja2.defaults.DEFAULT_FILTERS['regex_escape'] = regex_escape
+
+
 def deprecated(func):
     # type: (Callable[..., Any]) -> Callable[..., Any]
 
@@ -490,7 +512,7 @@ class Command(LoggerMixin, object):
 
         self._command = None  # type: Optional[List[str]]
         self._popen_kwargs = None  # type: Optional[Dict[str, Any]]
-        self._process = None  # type: Optional[subprocess.Popen]
+        self._process = None  # type: Optional[subprocess.Popen[str]]
         self._exit_code = None  # type: Optional[int]
 
         self._stdout = None  # type: Optional[str]
@@ -507,10 +529,10 @@ class Command(LoggerMixin, object):
             return self.executable + self.options
 
         # escape apostrophes in strings and adds them around strings with space
+        # pylint: disable=line-too-long
         return [('"{}"'.format(option.replace('"', r'\"')) if ' ' in option and not
                  (
-                     (option.startswith('"') and option.endswith('"')) or
-                     (option.startswith("'") and option.endswith("'")))
+                     (option.startswith('"') and option.endswith('"')) or (option.startswith("'") and option.endswith("'")))  # Ignore PEP8Bear
                  else option) for option in self.executable + self.options]
 
     def _communicate_batch(self):
@@ -877,7 +899,7 @@ def requests(logger=None):
 
     # Start capturing ``print`` statements - they are used to provide debug messages, therefore
     # using ``debug`` level.
-    with print_wrapper(log_fn=http_client_logger.debug):  # type: ignore  # logger.debug signature is compatible
+    with print_wrapper(log_fn=http_client_logger.debug):
         # To log responses and their content, we must take a look at ``Response`` instance
         # returned by several entry methods (``get``, ``post``, ...). To do that, we have
         # a simple wrapper function.
@@ -1274,7 +1296,7 @@ class SimplePatternMap(LoggerMixin, object):
             pattern = _render_template(pattern)
             result = _render_template(result)
 
-            log_dict(logger.debug,  # type: ignore  # logger.debug signature is compatible
+            log_dict(self.logger.debug,
                      "rendered mapping '{}'".format(pattern),
                      result)
 
@@ -1427,7 +1449,7 @@ class PatternMap(LoggerMixin, object):
             # To make mypy happy, let's collapse type of `pattern`.
             assert isinstance(pattern, six.string_types)
 
-            log_dict(logger.debug,  # type: ignore  # logger.debug signature is compatible
+            log_dict(self.logger.debug,
                      "rendered mapping '{}'".format(pattern),
                      converter_chains)
 
